/* HuliFontViewer - A simple java font character map viewer.
 * Copyright (C) 2004-2005 Timothy Robinson
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.huli.hulifontviewer;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.io.File;

public class Main implements ActionListener {
    private DrawCharacterMap charMap = null;
    private JPanel mainWindow = null;
    private String lastDir = null;

    public JPanel createContentPane() {
        JPanel vbox = new JPanel();
        vbox.setLayout(new BoxLayout(vbox, BoxLayout.Y_AXIS));
        int borderSize = 2;
        vbox.setBorder(BorderFactory.createEmptyBorder(borderSize, borderSize, borderSize, borderSize));

        charMap = new DrawCharacterMap();

        // panel for drawing
        /*
        JPanel panel = new JPanel();
        panel.setLayout(new GridLayout());
        panel.setBorder(BorderFactory.createEmptyBorder(30, 30, 10, 30));
        */

        JPanel hbox = new JPanel();
        hbox.setLayout(new BoxLayout(hbox, BoxLayout.X_AXIS));
        hbox.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
        vbox.add(hbox);

        JLabel label = new JLabel("Font Size: ");
        hbox.add(label);

        SpinnerNumberModel numModel = new SpinnerNumberModel(30, 8, 100, 1);
        JSpinner spinner = new JSpinner(numModel);
        spinner.addChangeListener(charMap);
        spinner.setMaximumSize(spinner.getMinimumSize());
        hbox.add(spinner);

        JCheckBox linesCheckBox = new JCheckBox("Show Metric Lines", true);
        linesCheckBox.addItemListener(charMap);
        hbox.add(linesCheckBox);

        hbox.add(Box.createHorizontalGlue());

        hbox = new JPanel();
        hbox.setLayout(new BoxLayout(hbox, BoxLayout.X_AXIS));
        hbox.setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
        vbox.add(hbox);

        charMap.reshape(0, 0, 200, 250);
        hbox.add(charMap);

        JScrollBar scrollBar = new JScrollBar(Adjustable.VERTICAL, 0, 7, 0, 20);
        scrollBar.addAdjustmentListener(charMap);
        charMap.setScrollBar(scrollBar);
        //charMap.setFontFileName("data/MusiQwik.ttf");
        //    "/usr/X11R6/lib/X11/fonts/truetype/slugfest.ttf"
        hbox.add(scrollBar);

        /*
        JButton button = new JButton("button");
        vbox.add(button);
        */

        mainWindow = vbox;

        return vbox;
    }

    public JMenuBar createMainMenu() {
        JMenuBar menuBar = new JMenuBar();

        menuBar.add(createFileMenu());

        return menuBar;
    }

    private JMenu createFileMenu() {
        JMenu menu = new JMenu("File");
        menu.setMnemonic(KeyEvent.VK_F);

        JMenuItem openMenuItem = new JMenuItem("Open");
        openMenuItem.addActionListener(this);
        menu.add(openMenuItem);

//        menu.addSeparator();

        JMenuItem quitMenuItem = new JMenuItem("Quit");
        quitMenuItem.addActionListener(this);
        menu.add(quitMenuItem);

        return menu;
    }

    public void actionPerformed(ActionEvent e) {
        /*
        JMenuItem source = (JMenuItem)e.getSource();
        String s = "Action event detected.\n"
                   + "    Event source: " + source.getText()
                   + " (an instance of " + getClassName(source) + ")\n";
        System.out.println(s);
        */

        if ("Open".equals(e.getActionCommand())) {
            runFileOpenDialog();
        } else if ("Quit".equals(e.getActionCommand())) {
            System.exit(0);
        }
    }

    private void runFileOpenDialog() {
        JFileChooser chooser = new JFileChooser(lastDir);
        int retVal = chooser.showOpenDialog(mainWindow);
        if (retVal == JFileChooser.APPROVE_OPTION) {
        try {
            File file = chooser.getSelectedFile();
            /*
            System.out.println("getPath: " + file.getPath());
            System.out.println("getAbsolutePath: " + file.getAbsolutePath());
            System.out.println("getCanonicalPath: " + file.getCanonicalPath());
            System.out.println("getParent: " + file.getParent());
            */
            charMap.setFontFileName(file.getAbsolutePath());
            lastDir = file.getParent();
        } catch (Exception e) {
        }
        }
    }

    // Returns just the class name -- no package info.
    protected String getClassName(Object o) {
        String classString = o.getClass().getName();
        int dotIndex = classString.lastIndexOf(".");
        return classString.substring(dotIndex+1);
    }

    /**
     * Create the GUI and show it.  For thread safety,
     * this method should be invoked from the
     * event-dispatching thread.
     */
    private static void createAndShowGUI() {
        JFrame frame = new JFrame("HuliFontViewer");

        Main main = new Main();

        frame.setJMenuBar(main.createMainMenu());
        frame.getContentPane().add(main.createContentPane());

//        frame.setSize(new Dimension(200, 200));
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.pack();
        frame.setVisible(true);
    }

    public static void main(String[] args) {
        //Schedule a job for the event-dispatching thread:
        //creating and showing this application's GUI.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                createAndShowGUI();
            }
        });
    }
}

